==> dart_cure-0.0.3.tar.gz: test/net_test.dart <==
import 'package:dart_cure/net/http.dart';
import 'package:test/test.dart';

void main() {
  test('HTTPClient.getAsync()', () async {
    final client = HTTPClient();
    try {
      final uri =
          'https://geoapi.heweather.net/v2/city/lookup?location=beij&key=xxx';
      final response = await client.getAsync(uri);
      final actual = response.content;
      final matcher = '{"code":"401"}';
      expect(actual, matcher);
    } finally {
      client.close();
    }
  });

  test('HTTPClient.postAsync()', () async {
    final client = HTTPClient();
    try {
      final uri = 'http://api.build.const.cc/Entry/v1/Profiles';
      final content =
          '{"devicePlatform": "Android", "appBuild": "7", "language": "zh-CN"}';
      final response = await client.postAsync(uri, content);
      final actual = response.content;
      final matcher =
          '{"updateInfo":{"msg":"- 更新框架\\r\\n- 优化用户界面体验\\r\\n- 修复了一些问题","updateType":"2","downUrl":"https://cloud.build.const.cc/App/Downloads/AdditelLink.apk","downVersion":"2.4.2"},"identityProviderUrl":"http://idp.build.const.cc/","linkCrabAPIUrl":"http://crab.build.const.cc/","linkDBAPIUrl":"http://api.build.const.cc/DB/","linkSiteUrl":"http://link.build.const.cc/","logServiceUrl":"http://api.build.const.cc/log/","userSiteUrl":"http://account.build.const.cc/","avatarUrl":"http://account.build.const.cc/userlogos/","userAPIUrl":"http://api.build.const.cc/Account/"}';
      expect(actual, matcher);
    } finally {
      client.close();
    }
  });
}

==> dart_cure-0.0.4.tar.gz: test/net_test.dart <==
import 'package:dart_cure/net/http.dart';
import 'package:test/test.dart';

void main() {
  test('HTTPClient.getAsync()', () async {
    final client = HTTPClient();
    try {
      final uri =
          'https://geoapi.heweather.net/v2/city/lookup?location=beij&key=xxx';
      final response = await client.getAsync(uri);
      final actual = response.content;
      final matcher = '{"code":"401"}';
      expect(actual, matcher);
    } finally {
      client.close();
    }
  });

  test('HTTPClient.postAsync()', () async {
    final client = HTTPClient();
    try {
      final uri = 'http://api.build.const.cc/Entry/v1/Profiles';
      final content =
          '{"devicePlatform": "Android", "appBuild": "7", "language": "zh-CN"}';
      final response = await client.postAsync(uri, content, ContentType.json);
      final actual = response.content;
      final matcher =
          '{"updateInfo":{"msg":"- 更新框架\\r\\n- 优化用户界面体验\\r\\n- 修复了一些问题","updateType":"2","downUrl":"https://cloud.build.const.cc/App/Downloads/AdditelLink.apk","downVersion":"2.4.2"},"identityProviderUrl":"http://idp.build.const.cc/","linkCrabAPIUrl":"http://crab.build.const.cc/","linkDBAPIUrl":"http://api.build.const.cc/DB/","linkSiteUrl":"http://link.build.const.cc/","logServiceUrl":"http://api.build.const.cc/log/","userSiteUrl":"http://account.build.const.cc/","avatarUrl":"http://account.build.const.cc/userlogos/","userAPIUrl":"http://api.build.const.cc/Account/"}';
      expect(actual, matcher);
    } finally {
      client.close();
    }
  });
}
